@@ -385,6 +385,8 @@ let file_completed (file : file) =
   try
     let impl = as_file_impl file in
     if impl.impl_file_state = FileDownloading then begin
+        CommonSwarming.duplicate_chunks ();
+        set_file_release file false (admin_user ());
         files =:= List2.removeq file !!files;
         done_files =:= file :: !!done_files;
         update_file_state impl FileDownloaded;
@@ -523,13 +525,55 @@ let display_bw_stats = ref false
 
 let start_download file =
   if !!pause_new_downloads then file_pause file (admin_user ());
+  if !!release_new_downloads then set_file_release file true (admin_user ());
   if !!file_started_cmd <> "" then
+    begin
+      let info = file_info file in
+      let temp_name = file_disk_name file in
+      let file_id = Filename.basename temp_name in
+      let size = Int64.to_string (file_size file) in
+      let network = network_find_by_num info.G.file_network in
+      let filename = file_best_name file in
+      let file_group_info =
+        match file_group file with
+        | None -> 0, []
+        | Some _ ->
+          let users = ref [] in
+          let counter = ref 0 in
+          user2_users_iter (fun u ->
+            if file_owner file <> u &&
+              user2_can_view_file u (file_owner file) (file_group file) then
+                begin
+                  incr counter;
+                  users :=  (Printf.sprintf "FILE_GROUP_USER_%d" !counter, u.user_name) ::
+                            (Printf.sprintf "FILE_GROUP_DIR_%d" !counter, u.user_commit_dir) :: !users
+                end);
+          !counter, !users
+      in
       MlUnix.fork_and_exec  !!file_started_cmd
       [|
       !!file_started_cmd;
         "-file";
         string_of_int (CommonFile.file_num file);
       |]
+     ~vars:([("TEMPNAME",  temp_name);
+	    ("FILEID",    file_id);
+	    ("FILESIZE",  size);
+	    ("FILENAME",  filename);
+	    ("FILEHASH",  string_of_uids info.G.file_uids);
+	    ("DLFILES",   string_of_int (List.length !!files)); 
+	    ("NETWORK",   network.network_name);
+	    ("ED2K_HASH", (file_print_ed2k_link filename (file_size file) info.G.file_md4));
+	    ("FILE_OWNER",(file_owner file).user_name);
+	    ("FILE_GROUP",user2_print_group (file_group file));
+	    ("USER_MAIL", ( if (file_owner file).user_mail <> "" then
+                              (file_owner file).user_mail
+                            else
+                              if !!mail <> "" then !!mail else ""));
+	    ("FILE_GROUP_CNT", string_of_int (fst (file_group_info)));
+	    ]
+            @ snd (file_group_info))
+    end
 
 let download_file o arg =
   let user = o.conn_user in
@@ -583,7 +627,6 @@ let print_connected_servers o =
           List.mem NetworkHasSupernodes r.network_flags
         then begin
            if use_html_mods o then begin
-               Printf.bprintf buf "\\<div class=servers\\>";
                html_mods_table_one_row buf "serversTable" "servers" [
                  ("", "srh", Printf.sprintf (_b "--- Connected to %d servers on the %s network ---\n")
                    (List.length list) r.network_name); ]
@@ -591,7 +634,6 @@ let print_connected_servers o =
            else
              Printf.bprintf buf (_b "--- Connected to %d servers on the %s network ---\n")
                (List.length list) r.network_name;
-           if use_html_mods o then Printf.bprintf buf "\\</div\\>";
           end;
          if use_html_mods o && List.length list > 0 then server_print_html_header buf "C";
 
