@@ -310,7 +310,7 @@ Use '$rhelp command$n' or '$r? command$n' for help on a command.
         let user, pass =
           match args with
             [] -> failwith "Usage: auth <user> <password>"
-          | [s1] -> admin_user.CommonTypes.user_name, s1
+          | [s1] -> (admin_user ()).CommonTypes.user_name, s1
           | user :: pass :: _ -> user, pass
         in
         if valid_password user pass then begin
@@ -342,8 +342,9 @@ let calendar_options = {
     conn_output = TEXT;
     conn_sortvd = NotSorted;
     conn_filter = (fun _ -> ());
-    conn_user = default_user;
+    conn_user = find_ui_user CommonUserDb.admin_user_name;
     conn_width = 80; conn_height = 0;
+    conn_info = Some (CALENDAR, (Ip.null, 0));
   }
 
 let check_calendar () =
@@ -558,19 +559,6 @@ let user_closed sock  msg =
   user_socks := List2.removeq sock !user_socks;
   ()
 
-(* Here, we clearly need a good html parser to remove tags, and to translate
-special characters. Avoid them in the meantime. *)
-let text_of_html html =
-  String2.convert false (fun buf state c ->
-    if state then
-      c <> '>'
-    else
-      if c = '<' then true else begin
-        Buffer.add_char buf c;
-        false
-      end
-) html
-
 let telnet_handler t event =
   match event with
     TcpServerSocket.CONNECTION (s, Unix.ADDR_INET (from_ip, from_port)) ->
@@ -581,7 +569,7 @@ let telnet_handler t event =
           "telnet connection"
           s in
         let telnet = {
-            telnet_auth = ref (has_empty_password admin_user);
+            telnet_auth = ref (has_empty_password (admin_user ()));
             telnet_iac = false;
             telnet_wait = 0;
             telnet_buffer = Buffer.create 100;
@@ -591,9 +579,10 @@ let telnet_handler t event =
             conn_output = (if !!term_ansi then ANSI else TEXT);
             conn_sortvd = NotSorted;
             conn_filter = (fun _ -> ());
-            conn_user = default_user;
+            conn_user = find_ui_user CommonUserDb.admin_user_name;
             conn_width = 80;
             conn_height = 0;
+            conn_info = Some (TELNET, (from_ip, from_port));
           } in
 	(match Ip_set.match_ip !allowed_ips_set from_ip with
 	| Some br -> 
@@ -682,6 +671,7 @@ let extension_to_file_ext extension =
   | "jpeg"
   | "jpg" -> JPEG
   | "js" -> JAVASCRIPT
+  | "vob"
   | "mpe"
   | "mpeg"
   | "mpg" -> MPEG
@@ -821,18 +811,21 @@ let http_add_bin_stream_header r ext =
 
 let http_send_bin r buf filename =
   let file_to_send =
-    try
-      File.to_string filename
-    with _ ->
+    if theme_page_exists filename then
+      File.to_string (get_theme_page filename)
+    else
       try
-        Hashtbl.find CommonPictures.files filename
-      with Not_found ->
+        File.to_string filename
+      with _ ->
         try
-          if String.sub filename 0 4 = "flag" then
-            Hashtbl.find CommonPictures.files "flag_--.png"
-          else
-            raise Not_found
-        with _ -> raise Not_found
+          Hashtbl.find CommonPictures.files filename
+        with Not_found ->
+          try
+            if String.sub filename 0 4 = "flag" then
+              Hashtbl.find CommonPictures.files "flag_--.png"
+            else
+              raise Not_found
+          with _ -> raise Not_found
   in
   let ext = extension_to_file_ext (Filename2.last_extension2 filename) in
   http_add_bin_header r ext (String.length file_to_send);
@@ -867,7 +860,7 @@ let html_open_page buf t r open_body =
       let this_page = "dheader.html" in
       Buffer.add_string buf
         (
-                if !!html_mods_theme != "" && theme_page_exists this_page then
+                if !!html_mods_theme <> "" && theme_page_exists this_page then
                         read_theme_page this_page else
                         if !!html_mods then !!CommonMessages.download_html_header_mods0
                         else !!CommonMessages.download_html_header_old);
@@ -878,7 +871,7 @@ let html_open_page buf t r open_body =
    
         let this_page = "header.html" in
     Buffer.add_string buf (
-                if !!html_mods_theme != "" && theme_page_exists this_page then
+                if !!html_mods_theme <> "" && theme_page_exists this_page then
                         read_theme_page this_page else
                         if !!html_mods then !!CommonMessages.html_header_mods0
                         else !!CommonMessages.html_header_old);
@@ -920,6 +913,8 @@ let send_preview r file fd size filename exten =
       else String.lowercase (String.sub exten 1 (len - 1)) in
   http_add_bin_stream_header r (extension_to_file_ext exten);
 
+  add_reply_header r "Content-Disposition"
+  (Printf.sprintf "inline;filename=\"%s\"" (Filename.basename filename)); 
   let s = String.create 200000 in
   set_max_output_buffer r.sock (String.length s);
   set_rtimeout r.sock 10000.;
@@ -954,10 +949,10 @@ let http_handler o t r =
 	 List.iter (fun (arg, value) -> Printf.bprintf b " %s %s" arg value) r.get_url.Url.args;
 	 if Buffer.contents b <> "" then Printf.sprintf "(%s)" (Buffer.contents b) else "");
 
-  let user = if r.options.login = "" then admin_user.CommonTypes.user_name else r.options.login in
-  if not (valid_password user r.options.passwd) then begin
+  let user = if r.options.login = "" then (admin_user ()).CommonTypes.user_name else r.options.login in
+  if not (valid_password user r.options.passwd) || (r.get_url.Url.short_file = "logout") then begin
       clear_page buf;
-      http_file_type := HTM;
+      http_file_type := TXT;
       let _, error_text_long, header = Http_server.error_page "401" "" ""
 	(Ip.to_string (TcpBufferedSocket.my_ip r.sock))
 	(string_of_int !!http_port) None in
@@ -971,8 +966,10 @@ let http_handler o t r =
     begin
       let user = find_ui_user user  in
       let o = match user.ui_http_conn with
-          Some oo -> oo.conn_buf <- o.conn_buf; oo
-        | None -> let oo = { o with conn_user = user } in
+          Some oo -> oo.conn_buf <- o.conn_buf;
+            oo.conn_info <- Some (WEB, peer_addr t); oo
+        | None -> let oo = { o with conn_user = user;
+                                    conn_info = Some (WEB, peer_addr t)} in
             user.ui_http_conn <- Some oo; oo
       in
       try
@@ -1040,7 +1037,7 @@ let http_handler o t r =
             html_open_page buf t r true;
             let this_page = "commands.html" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.web_common_header_mods0
               else !!CommonMessages.web_common_header_old)
@@ -1048,14 +1045,14 @@ let http_handler o t r =
             html_open_page buf t r true;
             let this_page = "multidllink.html" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.multidllink_mods0
               else !!CommonMessages.multidllink_old)
         | "" | "index.html" ->
                 html_open_page buf t r false;
                 let this_page = "frames.html" in
-                if !!html_mods_theme != "" && theme_page_exists this_page then
+                if !!html_mods_theme <> "" && theme_page_exists this_page then
                   Buffer.add_string buf (read_theme_page this_page) else
                 if !!html_mods then
                   (if !!html_frame_border then
@@ -1396,9 +1393,16 @@ let http_handler o t r =
 
               | [ "setoption", _ ; "option", name; "value", value ] ->
                   html_open_page buf t r true;
+                  let gui_type, ip, port =
+                    match o.conn_info with
+                    | None -> None, None, None
+                    | Some (gui_type, (ip, port)) -> Some gui_type, Some ip, Some port
+                  in
 		  if user2_is_admin o.conn_user.ui_user then
 		    begin
-                      CommonInteractive.set_fully_qualified_options name value;
+                      CommonInteractive.set_fully_qualified_options name value
+                        ~user:(Some o.conn_user.ui_user.CommonTypes.user_name)
+                        ~ip:ip ~port:port ~gui_type:gui_type ();
                       Buffer.add_string buf "Option value changed"
 		    end
 		  else
@@ -1463,7 +1467,7 @@ let http_handler o t r =
             http_add_text_header r CSS;
             let this_page = "h.css" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !CommonMessages.html_css_mods
               else !!CommonMessages.html_css_old)
@@ -1473,7 +1477,7 @@ let http_handler o t r =
             http_add_text_header r CSS;
             let this_page = "dh.css" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !CommonMessages.download_html_css_mods
               else !!CommonMessages.download_html_css_old)
@@ -1483,7 +1487,7 @@ let http_handler o t r =
             http_add_text_header r JAVASCRIPT;
             let this_page = "i.js" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.html_js_mods0
               else !!CommonMessages.html_js_old)
@@ -1493,7 +1497,7 @@ let http_handler o t r =
             http_add_text_header r JAVASCRIPT;
             let this_page = "di.js" in
             Buffer.add_string buf (
-              if !!html_mods_theme != "" && theme_page_exists this_page then
+              if !!html_mods_theme <> "" && theme_page_exists this_page then
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.download_html_js_mods0
               else !!CommonMessages.download_html_js_old)
@@ -1521,7 +1525,7 @@ let http_handler o t r =
   in
   r.reply_content <- 
     if !http_file_type <> BIN && !!html_use_gzip then 
-      Autoconf.zlib__gzip_string s 
+      Zlib.gzip_string s 
     else s
 
 let http_options = {
@@ -1529,8 +1533,9 @@ let http_options = {
     conn_output = HTML;
     conn_sortvd = NotSorted;
     conn_filter = (fun _ -> ());
-    conn_user = default_user;
+    conn_user = find_ui_user CommonUserDb.admin_user_name;
     conn_width = 80; conn_height = 0;
+    conn_info = Some (WEB, (Ip.null, 0));
   }
 
 let create_http_handler () =
@@ -1539,6 +1544,7 @@ let create_http_handler () =
       port = !!http_port;
       requests = [];
       addrs = Ip_set.of_list !!allowed_ips;
+(* do not limit access to MLDonkey web interface by IP blocklist *)
       use_ip_block_list = false;
       base_ref = "";
       default = http_handler http_options;
