@@ -1083,7 +1083,7 @@ let simple_print_file_list finished buf files format =
       ) files)
 
 let print_bw_stats buf =
-  Printf.bprintf buf "Down: %.1f KB/s ( %d + %d ) | Up: %.1f KB/s ( %d + %d ) | Shared: %d/%s | Uploaded: %s"
+  Printf.bprintf buf "Down: %.1f KB/s ( %d + %d ) | Up: %.1f KB/s ( %d + %d ) | Shared: %d/%s | Downloaded: %s | Uploaded: %s"
        (( (float_of_int !udp_download_rate) +. (float_of_int !control_download_rate)) /. 1024.0)
          !udp_download_rate
          !control_download_rate
@@ -1092,6 +1092,7 @@ let print_bw_stats buf =
          !control_upload_rate
          !nshared_files
   (size_of_int64 !nshared_bytes)
+  (size_of_int64 !download_counter)
   (size_of_int64 !upload_counter)
 
 let console_topic () =
@@ -1969,12 +1970,21 @@ let runinfo html buf o =
   let list = ref [] in
   tack list
     (
-      "User:\t\t", 
-      Printf.sprintf "%s (%s) - uptime: %s" 
+      "MLDonkey user:\t\t", 
+      Printf.sprintf "%s (%s) - uptime: %s%s"
 	o.conn_user.ui_user.user_name
 	(if has_empty_password o.conn_user.ui_user then "Warning: empty Password"
 	else "PW Protected")
 	(Date.time_to_string (last_time () - start_time) "verbose")
+        (
+        let user_group =
+          (try Some (Unix.getpwuid (Unix.getuid())).Unix.pw_name with _ -> None),
+          (try Some (Unix.getgrgid (Unix.getgid())).Unix.gr_name with _ -> None)
+        in
+        match user_group with
+        | (Some g, Some u) -> Printf.sprintf " - running as %s:%s" u g
+        | _ -> ""
+        )
     );
   tack list
     (
@@ -1985,6 +1995,7 @@ let runinfo html buf o =
 	 (Autoconf.donkey = "yes" && !!enable_overnet, "Overnet");
 	 (Autoconf.donkey = "yes" && !!enable_kademlia, "Kademlia");
 	 (Autoconf.bittorrent = "yes" && !!enable_bittorrent, "BitTorrent");
+	 (Autoconf.direct_connect = "yes" && !!enable_directconnect, "DirectConnect");
 	 (Autoconf.fasttrack = "yes" && !!enable_fasttrack, "Fasttrack");
 	 (Autoconf.gnutella = "yes" && !!enable_gnutella, "Gnutella");
 	 (Autoconf.gnutella2 = "yes" && !!enable_gnutella2, "G2");
@@ -2127,6 +2138,7 @@ let diskinfo html buf =
   let list = ref [] in
   ignore (search_incoming_files ());
   ignore (search_incoming_directories ());
+  list := (Filename2.temp_dir_name (), "$MLDONKEY_TEMP") :: !list;
   List.iter (fun dir ->
      list := (dir.shdir_dirname, (Printf.sprintf "shared (%s)" dir.shdir_strategy))
      :: !list) !!shared_directories;
@@ -2231,11 +2243,11 @@ let dllink_print_result html url header results =
   if html then Printf.bprintf buf "\\</tr\\>\\</table\\>\\</div\\>\\</div\\>";
   Buffer.contents buf
 
-let dllink_query_networks html url user =
+let dllink_query_networks html url user group =
   let result = ref [] in
   if not (networks_iter_until_true (fun n ->
     try
-      let s,r = network_parse_url n url user in
+      let s,r = network_parse_url n url user group in
         if s = "" then
           r
         else
@@ -2287,14 +2299,14 @@ let dllink_parse html url user =
       let concat_headers =
         (List.fold_right (fun (n, c) t -> n ^ ": " ^ c ^ "\n" ^ t) headers "")
       in
-      ignore (dllink_query_networks html concat_headers user)
+      ignore (dllink_query_networks html concat_headers user user.user_default_group)
     );
     dllink_print_result html url "Parsing HTTP url" [])
   else
     if (String2.starts_with url "ftp") then
-      dllink_query_networks html (Printf.sprintf "Location: %s" url) user
+      dllink_query_networks html (Printf.sprintf "Location: %s" url) user user.user_default_group
     else
-      dllink_query_networks html url user
+      dllink_query_networks html url user user.user_default_group
 
 module UnionFind = struct
   type t = int array
@@ -2511,7 +2523,7 @@ let print_upstats o list server =
 	  ("", "sr ar", Printf.sprintf "%5.1f" ( if size < 1.0 then 0.0 else (uploaded *. 100.) /. size));
 	  ("", "sr", Printf.sprintf "\\<a href=\\\"preview_upload?q=%d\\\"\\>P\\</a\\>" impl.impl_shared_num);
 	  ("", "sr", (if impl.impl_shared_id = Md4.null then
-		        (Filename.basename impl.impl_shared_codedname)
+		        (shorten (Filename.basename impl.impl_shared_codedname) !!max_name_len)
 		      else
 			Printf.sprintf "\\<a href=\\\"%s\\\"\\>%s\\</a\\>"
 			  ed2k (shorten (Filename.basename impl.impl_shared_codedname) !!max_name_len)));
