@@ -28,7 +28,7 @@ let bittorrent_section = file_section bittorrent_ini ["Bittorrent"] "Bittorrent
 let client_port = define_option bittorrent_section ["client_port"]
   ~restart: true
   "The port to bind the client to"
-    int_option 6882
+    port_option 6882
 
 (* Generate client_uid *)
 (* current_version could be "2.6.6.CVS" (why send the dots?)
@@ -90,7 +90,7 @@ let max_uploaders_per_torrent = define_option bittorrent_section ["max_uploaders
 
 let max_bt_uploaders = define_option bittorrent_section ["max_bt_uploaders"]
   "Maximum number of uploaders for bittorrent"
-    int_option 5
+    int_option 3
 
 (* numwant: Optional. Number of peers that the client would like to receive from the tracker.
 This value is permitted to be zero. If omitted, typically defaults to 50 peers.   *)
@@ -101,22 +101,30 @@ let numwant = define_option bittorrent_section ["numwant"]
 
 let import_new_torrents_interval = define_option bittorrent_section ["import_new_torrents_interval"]
   ~restart: true
-  "Interval in seconds 'torrents/incoming' is scanned for new torrent files to be downloaded,
-  0 to deactivate, changes require restart"
+  "Interval in seconds 'torrents/incoming' is scanned for new torrent files to be downloaded, 0 to deactivate"
     float_option 60.
 
 let tracker_retries = define_option bittorrent_section ["tracker_retries"]
   "Number of retries before a tracker is disabled, use 0 to not disable trackers"
     int_option 10
 
+let check_bt_uploaders () =
+  if !!max_bt_uploaders > !!max_upload_slots then
+    max_bt_uploaders =:= !!max_upload_slots
+
 let _ =
   begin
     option_hook max_uploaders_per_torrent
       (fun _ ->
-        if !!max_uploaders_per_torrent < 1 then max_uploaders_per_torrent =:= 5);
+        let v = int_of_string (strings_of_option max_uploaders_per_torrent).option_default in
+        if !!max_uploaders_per_torrent < 1 then max_uploaders_per_torrent =:= v);
     option_hook max_bt_uploaders
       (fun _ ->
-        if !!max_bt_uploaders < 0 then max_bt_uploaders =:= 5);
+        let v1 = int_of_string (strings_of_option max_upload_slots).option_default in
+        let v2 = int_of_string (strings_of_option max_bt_uploaders).option_default in
+        if !!max_bt_uploaders < 1 || !!max_bt_uploaders > v1 then max_bt_uploaders =:= v2;
+	check_bt_uploaders ()
+        );
     option_hook max_tracker_redirect   (** #4541 [egs] **)
       (fun _ ->
         if !!max_tracker_redirect < 0 then max_tracker_redirect =:= 0
